@@ -1,4 +1,4 @@
 from np_session.components import *
 from np_session.databases import *
-from np_session.np_session import *
+from np_session.session import *
 from np_session.utils import *
